@@ -119,7 +119,7 @@ function(y,
 		 ymat2[ymat2[,2]==-999,2] <- 10^10
 		 ll <- ymat2[,1]
 		 rr <- ymat2[,2]
-		 library(survival)
+		 #library(survival)
 		 fit0 <- survreg(formula = Surv(time=ll,time2=rr,type="interval2") ~ xce-1, dist = "lognormal")
 
 		 betace <- coefficients(fit0)
